@@ -30,6 +30,15 @@ sql_l = '''(
     )
     '''
 
+sql_index = '''(
+    `ID` bigint not null AUTO_INCREMENT,
+    `TDATE`  date not null,
+    `CLOSE` float,
+    `FACTOR`  varchar(255),
+    primary key (`ID`)
+    )
+    '''
+
 sql_info1 = sql_user_work
 sql_path1 = sql_write_path_work['daily']
 
@@ -50,19 +59,94 @@ def factor_table_gen(table, sql_info=sql_info1):
         print(table + ' exists')
 
 
-def get_last_position(table, before_date, strategy, sql_path=sql_path1):
+def index_table_gen(table, sql_info=sql_info1):
+    try:
+        generate_table(
+            database='daily_data',
+            table=table,
+            generate_sql=sql_index,
+            sql_ip=sql_info['ip'],
+            sql_user=sql_info['user'],
+            sql_pass=sql_info['pass'],
+            table_comment='CTA INDEX'
+        )
+        print(table + ' generated')
+    except pymysql.err.InternalError:
+        print(table + ' exists')
+
+
+def index_gen(table_factor='cta_factor', table_index='cta_index', sql_path=sql_path1):
+    index_table_gen(table=table_index)
+    factors = pd.read_sql_query(
+        'select distinct FACTOR from ' + table_factor, sql_path
+    )
+    end_date_all = pd.read_sql_query(
+        'select distinct TDATE from ' + table_factor + ' order by TDATE desc limit 1', sql_path
+    )
+    if len(factors) == 0:
+        print('No factor return')
+        return
+    else:
+        for i in range(len(factors['FACTOR'])):
+            # factor = 'xswr_d1_q75'
+            factor = factors['FACTOR'][i]
+            last_factor_index = pd.read_sql_query(
+                'select * from ' + table_index + ' where FACTOR=\'' + factor
+                + '\' order by TDATE desc limit 1',
+                sql_path
+            )
+            if len(last_factor_index) == 0:
+                date0 = datetime(1990, 1, 1).date()
+                index0 = 1000
+            else:
+                date0 = last_factor_index['TDATE'][0]
+                index0 = last_factor_index['CLOSE'][0]
+
+            print(
+                str(i + 1) + '/' + str(len(factors['FACTOR'])) + ', '
+                + factor + ', start date: ' + date0.strftime('%Y-%m-%d')
+            )
+
+            if date0 == end_date_all['TDATE'][0]:
+                print('\tNo new date, ' + date0.strftime('%Y-%m-%d'))
+                continue
+
+            factor_data = pd.read_sql_query(
+                'select * from ' + table_factor + ' where TDATE>' + date0.strftime('%Y%m%d')
+                + ' and FACTOR=\'' + factor + '\' order by TDATE',
+                sql_path
+            )
+            if len(factor_data) > 0:
+                factor_data['RETURN'] = factor_data['RETURN'] * factor_data['WEIGHT'] * factor_data['POS']
+                factor_data_g = factor_data.groupby(by='TDATE').sum()[['RETURN']].reset_index()
+                factor_data_g['ret'] = factor_data_g['RETURN'] / 10000 + 1.0
+                factor_data_g['CLOSE'] = factor_data_g['ret'].cumprod()
+                factor_data_g['CLOSE'] = factor_data_g['CLOSE'] * index0
+                factor_data_g['FACTOR'] = factor
+                factor_data_g[['TDATE', 'CLOSE', 'FACTOR']].to_sql(
+                    table_index, sql_path, if_exists='append', index=False
+                )
+                print(
+                    '\t' + str(len(factor_data_g)) + ', to sql, '
+                    + factor_data_g['TDATE'][len(factor_data_g) - 1].strftime('%Y-%m-%d')
+                )
+            else:
+                print('\tNo new data')
+
+
+def get_last_position(table, before_date, factor, sql_path=sql_path1):
     existing_cal = pd.read_sql_query(
         'select distinct `TDATE` from ' + table + ' where `TDATE`<=' + before_date.strftime('%Y%m%d')
-        + ' and `FACTOR`=\'' + strategy + '\' order by `TDATE` desc limit 1',
+        + ' and `FACTOR`=\'' + factor + '\' order by `TDATE` desc limit 1',
         sql_path
     )
     if len(existing_cal) >= 1:
         pos = pd.read_sql_query(
             'select * from ' + table + ' where `TDATE`=' + existing_cal['TDATE'][0].strftime('%Y%m%d')
-            + ' and `FACTOR`=\'' + strategy + '\'',
+            + ' and `FACTOR`=\'' + factor + '\'',
             sql_path
         )
-        print('load last date: ' + existing_cal['TDATE'][0].strftime('%Y-%m-%d'))
+        print(factor + ', load last date: ' + existing_cal['TDATE'][0].strftime('%Y-%m-%d'))
         return pos
 
     else:
@@ -70,21 +154,21 @@ def get_last_position(table, before_date, strategy, sql_path=sql_path1):
         return None
 
 
-def load_factor(factor_name, table_index='cta_factor', sql_path=sql_path1):
+def load_factor(factor_name, table='cta_factor', sql_path=sql_path1):
     index = factor_name
 
     data = pd.read_sql_query(
-        'select * from ' + table_index + ' where FACTOR=\'' + index + '\'',
+        'select * from ' + table + ' where FACTOR=\'' + index + '\'',
         sql_path
     )
     return data
 
 
 def factor_stats(data, trade_days=250, show=False):
-    data['RETURN'] = data['RETURN'] * data['WEIGHT']
+    data['RETURN'] = data['RETURN'] * data['WEIGHT'] * data['POS']
     data_g = data.groupby(by='TDATE').sum()[['RETURN']].reset_index()
     # data_g = data.groupby(by='TDATE').mean()[['RETURN']].reset_index()
-    data_g['ret'] = data_g['RETURN'] + 1
+    data_g['ret'] = data_g['RETURN'] / 10000 + 1
     data_g['ind'] = data_g['ret'].cumprod()
     data_g['max_ind'] = data_g['ind'].cummax()
     cumulative_return = data_g['ind'][len(data_g) - 1] / data_g['ind'][0] - 1.0
@@ -184,18 +268,21 @@ def factor_compute(
         if 'hedge_ratio_list' in kwargs:
             for quantile in kwargs['hedge_ratio_list']:
                 index_name = factor_func.__name__ + '_d' + str(window_days) + '_q' + str(quantile)
-                exist_index = get_last_position(table=to_table, before_date=end_date, strategy=index_name)
+                exist_index = get_last_position(table=to_table, before_date=end_date, factor=index_name)
                 if exist_index is not None:
-                    start_date = exist_index['TDATE'][0]
+                    start_date0 = exist_index['TDATE'][0]
+                else:
+                    start_date0 = start_date
 
                 pos = factor_func(
-                    start_date=start_date,
+                    start_date=start_date0,
                     data=data,
                     window_days=window_days,
                     quantile=quantile,
-                    min_volume=min_volume
+                    min_volume=min_volume,
+                    **kwargs
                 )
-                if len(pos) > 0:
+                if pos is not None:
                     pos.to_sql(to_table, to_sql_path, if_exists='append', index=False)
                     print('\t' + index_name + ' to sql, ' + pos['TDATE'].tolist()[-1].strftime('%Y-%m-%d'))
                 else:
@@ -203,14 +290,22 @@ def factor_compute(
 
         else:
             index_name = factor_func.__name__ + '_d' + str(window_days)
-            exist_index = get_last_position(table=to_table, before_date=end_date, strategy=index_name)
+            exist_index = get_last_position(table=to_table, before_date=end_date, factor=index_name)
 
             if exist_index is not None:
-                start_date = exist_index['TDATE'][0]
+                start_date0 = exist_index['TDATE'][0]
+            else:
+                start_date0 = start_date
 
-            pos = factor_func(start_date=start_date, data=data, window_days=window_days, min_volume=min_volume)
-            if len(pos) > 0:
+            pos = factor_func(
+                start_date=start_date0, data=data, window_days=window_days, min_volume=min_volume, **kwargs
+            )
+            if pos is not None:
                 pos.to_sql(to_table, to_sql_path, if_exists='append', index=False)
                 print('\t' + index_name + ' to sql, ' + pos['TDATE'].tolist()[-1].strftime('%Y-%m-%d'))
             else:
                 print('\t' + index_name + ', no new data')
+
+
+if __name__ == '__main__':
+    index_gen()
