@@ -33,13 +33,13 @@ def performance_analysis(
     ret_all = data_df[[date_col]].copy()
     for i in funds:
         single_df = data_df[[date_col, i]]
-        data_before = single_df[single_df[date_col] < start_date][date_col].tolist()
-        if len(data_before) > 0:
-            start_date_lag1 = data_before[-1]
-        else:
-            start_date_lag1 = start_date
+        # data_before = single_df[single_df[date_col] < start_date][date_col].tolist()
+        # if len(data_before) > 0:
+        #     start_date_lag1 = data_before[-1]
+        # else:
+        #     start_date_lag1 = start_date
         single_df = single_df[
-            np.array(single_df[date_col] >= start_date_lag1) & np.array(single_df[date_col] <= end_date)
+            np.array(single_df[date_col] >= start_date) & np.array(single_df[date_col] <= end_date)
             ].reset_index(drop=True)
 
         single_data = single_df[single_df[i] > 0]
@@ -62,7 +62,10 @@ def performance_analysis(
             dd_days = single_df['dddg'].value_counts().reset_index().sort_values(by='index')
             if len(dd_days) > 1:
                 dd_days_hist = max(dd_days['dddg'].tolist()[1:])
-                dd_days_now = dd_days['dddg'].tolist()[-1]
+                if single_df['ddd'].tolist()[-1] == 0:
+                    dd_days_now = 0
+                else:
+                    dd_days_now = dd_days['dddg'].tolist()[-1]
             else:
                 dd_days_hist = np.nan
                 dd_days_now = np.nan
@@ -254,7 +257,10 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None):
             ret_last_week.append(single_df[i][len(single_df) - 2] / single_df[i][len(single_df) - 3] - 1)
             ret_this_4.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 5] - 1)
             ret_this_8.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 9] - 1)
-            ret_6_months.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 25] - 1)
+            try:
+                ret_6_months.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 25] - 1)
+            except:
+                ret_6_months.append(None)
         else:
             ret_this_week.append(None)
             ret_last_week.append(None)
@@ -386,18 +392,31 @@ def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_releas
 
     if data_type.lower() != 'alpha':
         funds_data = load_funds_data(
-            fund_list=fund_list, first_date=datetime(2000, 1, 1).date(), end_date=end_d,
-            db_path=db_path, cal_db_path=cal_db_path
+            fund_list=fund_list,
+            first_date=datetime(2000, 1, 1).date(),
+            end_date=end_d,
+            db_path=db_path,
+            cal_db_path=cal_db_path,
+            print_info=True
         )
         funds_data_monthly = load_funds_data(
-            fund_list=fund_list, first_date=start_d, end_date=end_d, freq='month',
-            db_path=db_path, cal_db_path=cal_db_path
+            fund_list=fund_list,
+            first_date=start_d,
+            end_date=end_d,
+            freq='month',
+            db_path=db_path,
+            cal_db_path=cal_db_path,
+            print_info=True
         )
 
     else:
         funds_data = load_funds_alpha(
-            fund_list=fund_list, first_date=datetime(2000, 1, 1).date(), end_date=end_d,
-            db_path=db_path, cal_db_path=cal_db_path
+            fund_list=fund_list,
+            first_date=datetime(2000, 1, 1).date(),
+            end_date=end_d,
+            db_path=db_path,
+            cal_db_path=cal_db_path,
+            print_info=True
         )
         nav_origin = funds_data['nav']
         funds_data = funds_data['eav']
