@@ -24,7 +24,7 @@ pymysql.install_as_MySQLdb()
 
 def nav_lines(
         fund_list, start_date, end_date, title='', zz=False, axis_cross=None,
-        db_path=sql_write_path_hb['daily'], cal_path=sql_write_path_hb['work'], all_selected=True
+        db_path=sql_write_path_hb['daily'], cal_path=sql_write_path_hb['work'], all_selected=True, print_info=True
 ):
     if axis_cross:
         axis_cross = opts.TooltipOpts(trigger="axis", axis_pointer_type="cross")
@@ -35,7 +35,8 @@ def nav_lines(
             first_date=start_date,
             end_date=end_date,
             db_path=db_path,
-            cal_db_path=cal_path
+            cal_db_path=cal_path,
+            print_info=print_info,
         )['eav']
     else:
         funds_data = load_funds_data(
@@ -44,6 +45,7 @@ def nav_lines(
             end_date=end_date,
             db_path=db_path,
             cal_db_path=cal_path,
+            print_info=print_info,
             # freq='',
             # fillna=False
         )
@@ -111,7 +113,7 @@ def nav_lines(
 
 def gen_grid(
         end_date, funds, zz=False, lookback_years=3, grid_width=1200, grid_height=500, pos_top=23, axis_cross=None,
-        db_path=sql_write_path_hb['work'], cal_path=sql_write_path_hb['daily'], all_selected=True
+        db_path=sql_write_path_hb['work'], cal_path=sql_write_path_hb['daily'], all_selected=True, print_info=True
 ):
     if axis_cross:
         axis_cross = opts.TooltipOpts(trigger="axis", axis_pointer_type="cross")
@@ -137,7 +139,8 @@ def gen_grid(
         zz=zz,
         db_path=db_path,
         cal_path=cal_path,
-        all_selected=all_selected
+        all_selected=all_selected,
+        print_info=print_info,
     )
 
     web2 = nav_lines(
@@ -147,7 +150,8 @@ def gen_grid(
         zz=zz,
         db_path=db_path,
         cal_path=cal_path,
-        all_selected=all_selected
+        all_selected=all_selected,
+        print_info=print_info,
     )
 
     grid_nav.add(
@@ -586,12 +590,18 @@ def chart_freq_dist(
     ).add_xaxis(
         xaxis_data=dist_df['label'].tolist()
     )
-    for i in funds:
+    for i in range(len(funds)):
+        f_name = funds[i]
+        if i == 0:
+            sel = True
+        else:
+            sel = False
         web.add_yaxis(
-            series_name=i,
-            y_axis=dist_df[i].tolist(),
+            series_name=f_name,
+            y_axis=dist_df[f_name].tolist(),
             stack='总量',
             label_opts=opts.LabelOpts(is_show=False),
+            is_selected=sel,
             # areastyle_opts=opts.AreaStyleOpts(opacity=0.5),
         )
 
