@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#coding:utf-8
 """
 净值归因模型
 """
@@ -11,9 +9,6 @@ from hbshare.rm_associated.util.exception import InputParameterError, Preprocess
 from hbshare.rm_associated.util.logger import logger
 from hbshare.rm_associated.util.data_loader import NavAttributionLoader
 from hbshare.rm_associated.util.regressions import Regression
-from hbshare.rm_associated.util.config import factor_map_dict
-from hbshare.rm_associated.util.plot_util import draw_summary_bar, draw_summary_bar_style, \
-    draw_area_line, draw_area_bar, draw_heatmap
 
 
 class StyleAttributionOutputs:
@@ -282,7 +277,7 @@ class StyleAttribution:
 
         return attr_summary, r_square_series, exposure_series, return_attr_series, total_attr_df, total_return_df
 
-    def get_all(self, isPlot=False):
+    def get_all(self):
         output = StyleAttributionOutputs()
 
         attr_summary, r_square_series, exposure_series, return_attr_series, total_attr_df, total_return_df = \
@@ -295,59 +290,13 @@ class StyleAttribution:
         output.style_allo_bar = total_attr_df
         output.style_allo_line = total_return_df
 
-        if isPlot:
-            if self.factor_type == 'style_allo':
-                factor_order = ['大盘价值', '大盘成长', '中盘价值', '中盘成长', '小盘价值', '小盘成长', '中证全债']
-                attribution_df = output.attribution_df.set_index('style_factor').reindex(factor_order)
-                attribution_df = (attribution_df * 100).round(2)
-                summary_bar = draw_summary_bar(attribution_df)
-                summary_bar.render('D:\\kevin\\净值归因示例\\style_allo\\summary_bar.html')
-
-                exposure_series = (output.exposure_series[factor_order] * 100).round(2)
-                exposure_area_line = draw_area_line(exposure_series, title="风格暴露时序分析")
-                exposure_area_line.render('D:\\kevin\\净值归因示例\\style_allo\\exposure_area_line.html')
-
-                return_attr_series = (output.return_attr_series[factor_order] * 100).round(2)
-                return_attr_stack_bar = draw_area_bar(return_attr_series, title="风格收益贡献时序分析")
-                return_attr_stack_bar.render('D:\\kevin\\净值归因示例\\style_allo\\return_attr_stack_bar.html')
-            elif self.factor_type == 'sector':
-                factor_order = ['大金融', '消费', 'TMT', '周期', '制造', '中证全债']
-                attribution_df = output.attribution_df.set_index('style_factor').reindex(factor_order)
-                attribution_df = (attribution_df * 100).round(2)
-                summary_bar = draw_summary_bar(attribution_df)
-                summary_bar.render('D:\\kevin\\净值归因示例\\sector\\summary_bar.html')
-
-                exposure_series = (output.exposure_series[factor_order] * 100).round(2)
-                exposure_area_line = draw_area_line(exposure_series, title="风格暴露时序分析")
-                exposure_area_line.render('D:\\kevin\\净值归因示例\\sector\\exposure_area_line.html')
-
-                return_attr_series = (output.return_attr_series[factor_order] * 100).round(2)
-                return_attr_stack_bar = draw_area_bar(return_attr_series, title="风格收益贡献时序分析")
-                return_attr_stack_bar.render('D:\\kevin\\净值归因示例\\sector\\return_attr_stack_bar.html')
-            else:
-                factor_order = list(factor_map_dict.keys())
-                attribution_df = output.attribution_df.set_index('style_factor').reindex(factor_order)
-                attribution_df['factor_exposure'] = attribution_df['factor_exposure'].round(2)
-                attribution_df['return_attr'] = (attribution_df['return_attr'] * 100).round(2)
-                attribution_df.index = attribution_df.index.map(factor_map_dict)
-                summary_bar = draw_summary_bar_style(attribution_df)
-                summary_bar.render('D:\\kevin\\净值归因示例\\style\\summary_bar.html')
-
-                exposure_series = output.exposure_series[factor_order].round(3)
-                exposure_series.columns = [factor_map_dict[x] for x in exposure_series.columns]
-                exposure_heatmap = draw_heatmap(exposure_series, title="因子暴露时序分析")
-                exposure_heatmap.render('D:\\kevin\\净值归因示例\\style\\exposure_heatmap.html')
-
         return output
 
 
 if __name__ == '__main__':
-    # a = ['000311', '110011', '161005', '166002', '162605']
-
     # 公募样例：110011
     # res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20181120', end_date='20210120',
     #                        factor_type='style_allo', benchmark_id='000300', nav_frequency='day').get_all(isPlot=True)
-
     # 私募样例
     res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20190220', end_date='20210120',
-                           factor_type='sector', benchmark_id='000300', nav_frequency='day').get_all(isPlot=True)
+                           factor_type='sector', benchmark_id='000300', nav_frequency='day').get_all()
