@@ -84,6 +84,23 @@ def _check_input(year, quarter):
 
 
 
+TIME_SOLT = [("2000","前一周"),
+            ("2007","近7天(1周）"),
+            ("2014","近14天(2周)"),
+            ("2028","近28天(4周)"),
+            ("2101","近1月"),
+            ("2102","近2月"),
+            ("2103","近2月"),
+            ("2106","近6月"),
+            ("2118","近18月"),
+            ("2201","近1年"),
+            ("2202","近2年"),
+            ("2203","近3年"),
+            ("2205","近5年"),
+            ("2210","近10年"),
+            ("2998","今年以来"),
+            ("2999","成立以来")]
+
 TIME_DICT = {"DAY":"jzrq", "WEEK": "tjrq", "MONTH": "tjyf", "YEAR": "tjnf"}
 
 def sql(k):
